@@ -8,6 +8,9 @@ from .iterator import IteratorGenerator
 from .iterator import IteratorSource
 from .json import DictToJsonParser
 from .json import JsonToDictParser
+from .json import SimdJsonParser
+from .json import StdDictToJsonParser
+from .json import StdJsonToDictParser
 from .json import JsonToDictParser as JSONParser  # For backward compatability
 from .json import JsonToDictParser as JSONParserProcessor  # For backward compatability
 from .jsonbytes import DictToJsonBytesParser
@@ -34,6 +37,9 @@ __all__ = (
 	'IteratorSource',
 	'DictToJsonParser',
 	'JsonToDictParser',
+	'SimdJsonParser',
+	'StdDictToJsonParser',
+	'StdJsonToDictParser',
 	'JSONParser',
 	'JSONParserProcessor',
 	'DictToJsonBytesParser',
