@@ -3,7 +3,7 @@ from .generator import DeclarativeGenerator
 from .timewindowanalyzer import DeclarativeTimeWindowAnalyzer
 
 from .builder import ExpressionBuilder
-from .builder import DeclarationError
+from .declerror import DeclarationError
 from .segmentbuilder import SegmentBuilder
 
 from .libraries import DeclarationLibrary
@@ -12,6 +12,8 @@ from .libraries import ZooKeeperDeclarationLibrary
 
 from .abc import Expression
 
+from .dot import declaration_to_dot
+
 __all__ = [
 	"DeclarativeProcessor",
 	"DeclarativeGenerator",
@@ -26,4 +28,6 @@ __all__ = [
 	"ZooKeeperDeclarationLibrary",
 
 	"Expression",
+
+	"declaration_to_dot",
 ]
