@@ -1,16 +1,33 @@
-import abc
 import functools
+import logging
+
+from .declerror import DeclarationError
+
+#
+
+L = logging.getLogger(__name__)
+
+#
 
 
-class Expression(abc.ABC):
+class Expression(object):
 
-	def __init__(self, app):
+	def __init__(self, app=None):
 		self.App = app
+		self.Location = None
 		self.Node = None  # The YAML node, assigned by a builder during YAML parsing
 
-	@abc.abstractmethod
 	def __call__(self, context, event, *args, **kwargs):
-		pass
+		raise RuntimeError("Call of the abstract method")
+
+	def set_location(self, location):
+		self.Location = location
+
+	def get_location(self):
+		return self.Location
+
+	def optimize(self):
+		return self
 
 
 class SequenceExpression(Expression):
@@ -36,7 +53,10 @@ class SequenceExpression(Expression):
 
 
 def evaluate(value, context, event, *args, **kwargs):
-	if isinstance(value, Expression):
-		return value(context, event, *args, **kwargs)
-	else:
-		return value
+	try:
+		if isinstance(value, Expression):
+			return value(context, event, *args, **kwargs)
+		else:
+			return value
+	except Exception as e:
+		raise DeclarationError(original_exception=e, location=value.get_location())
