@@ -13,12 +13,15 @@ L = logging.getLogger(__name__)
 #
 
 class DatagramSource(Source):
+
+
 	ConfigDefaults = {
 		'address': '127.0.0.1:8888',  # IPv4, IPv6 or unix socket path
 		'max_packet_size': 64 * 1024,
 		'receiver_buffer_size': 0,
 	}
 
+
 	def __init__(self, app, pipeline, id=None, config=None):
 		super().__init__(app, pipeline, id=id, config=config)
 		self.Loop = app.Loop
@@ -55,6 +58,7 @@ class DatagramSource(Source):
 
 		self.MaxPacketSize = int(self.Config['max_packet_size'])
 
+
 	async def main(self):
 		task = asyncio.ensure_future(self._receive(), loop=self.Loop)
 
@@ -65,6 +69,7 @@ class DatagramSource(Source):
 
 		self.Socket.close()
 
+
 	async def _receive(self):
 		while True:
 			try:
@@ -77,17 +82,20 @@ class DatagramSource(Source):
 				break
 
 			except Exception:
-				L.exception(f"Error in datagram source.")
+				L.exception("Error in datagram source.")
 				raise
 
 
 class DatagramSink(Sink):
+
+
 	ConfigDefaults = {
 		'address': '127.0.0.1:8888',  # IPv4, IPv6 or unix socket path
 		'max_packet_size': 64 * 1024,
 		'receiver_buffer_size': 0,
 	}
 
+
 	def __init__(self, app, pipeline, id=None, config=None):
 		super().__init__(app, pipeline, id=id, config=config)
 		self.Loop = app.Loop
@@ -124,5 +132,6 @@ class DatagramSink(Sink):
 
 		self.MaxPacketSize = int(self.Config['max_packet_size'])
 
+
 	def process(self, context, event):
 		self.Socket.send(event)
