@@ -1,11 +1,13 @@
 from .changestreamsource import MongoDBChangeStreamSource
 from .connection import MongoDBConnection
+from .source import MongoDBSource
 from .lookup import MongoDBLookup
 from .sink import MongoDBSink
 
 __all__ = (
 	'MongoDBConnection',
 	'MongoDBLookup',
+	'MongoDBSource',
 	'MongoDBChangeStreamSource',
 	'MongoDBSink',
 )
